@@ -6,8 +6,7 @@ module ParallelTests
     class Runner < ParallelTests::Test::Runner
       class << self
         def run_tests(test_files, process_number, num_processes, options)
-          cmd = [*executable, *options[:test_options], *color, *spec_opts, *test_files]
-          execute_command(cmd, process_number, num_processes, options)
+          execute_command(build_command(test_files, options), process_number, num_processes, options)
         end
 
         def determine_executable
@@ -42,6 +41,10 @@ module ParallelTests
           line =~ /\d+ examples?, \d+ failures?/
         end
 
+        def build_test_command(file_list, options)
+          [*executable, *options[:test_options], *color, *spec_opts, *file_list]
+        end
+
         # remove old seed and add new seed
         # --seed 1234
         # --order rand
